From 5a401e74359eafa9e6fc83c19051402270cb3662 Mon Sep 17 00:00:00 2001
From: Daniel Schoepe <daniel.schoepe@googlemail.com>
Date: Fri, 3 Jun 2011 15:42:35 +0200
Subject: [PATCH 2/2] emacs: A few tests for user-defined sections

---
 test/emacs                                         |   29 ++++++++++++++++++++
 .../notmuch-hello-new-section                      |   17 +++++++++++
 .../notmuch-hello-section-before                   |   18 ++++++++++++
 .../notmuch-hello-section-counts                   |   18 ++++++++++++
 .../notmuch-hello-section-hidden-tag               |   17 +++++++++++
 .../notmuch-hello-section-with-empty               |   17 +++++++++++
 6 files changed, 116 insertions(+), 0 deletions(-)
 create mode 100644 test/emacs.expected-output/notmuch-hello-new-section
 create mode 100644 test/emacs.expected-output/notmuch-hello-section-before
 create mode 100644 test/emacs.expected-output/notmuch-hello-section-counts
 create mode 100644 test/emacs.expected-output/notmuch-hello-section-hidden-tag
 create mode 100644 test/emacs.expected-output/notmuch-hello-section-with-empty

diff --git a/test/emacs b/test/emacs
index 792492f..7fea4ea 100755
--- a/test/emacs
+++ b/test/emacs
@@ -31,6 +31,35 @@ output=$(test_emacs '(notmuch-hello) (goto-char (point-min)) (re-search-forward
 expected=$(cat $EXPECTED/notmuch-hello-view-inbox)
 test_expect_equal "$output" "$expected"
 
+test_begin_subtest "User defined section with inbox tag"
+output=$(test_emacs "(setq notmuch-hello-sections '((:title \"Test:\" :type query-list :items ((\"inbox\" . \"tag:inbox\"))))) (notmuch-hello) (princ (buffer-string))")
+expected=$(cat $EXPECTED/notmuch-hello-new-section)
+test_expect_equal "$output" "$expected"
+
+test_begin_subtest "User defined section with empty, hidden entry"
+output=$(test_emacs "(setq notmuch-hello-sections '((:title \"Test-with-empty:\" :type query-list :items
+             ((\"inbox\" . \"tag:inbox\") (\"doesnotexist\" . \"tag:doesnotexist\"))
+             :hide-empty t)))
+             (notmuch-hello)
+             (princ (buffer-string))")
+expected=$(cat $EXPECTED/notmuch-hello-section-with-empty)
+test_expect_equal "$output" "$expected"
+
+test_begin_subtest "User defined section, unread tag filtered out"
+output=$(test_emacs "(setq notmuch-hello-sections '((:title \"Test-with-filtered:\" :type eachtag :hide-tags (\"unread\")))) (notmuch-hello) (princ (buffer-string))")
+expected=$(cat $EXPECTED/notmuch-hello-section-hidden-tag)
+test_expect_equal "$output" "$expected"
+
+test_begin_subtest "User defined section, different query for counts"
+output=$(test_emacs "(setq notmuch-hello-sections '((:title \"Test-with-counts:\" :type eachtag :make-count \"tag:signed\"))) (notmuch-hello) (princ (buffer-string))")
+expected=$(cat $EXPECTED/notmuch-hello-section-counts)
+test_expect_equal "$output" "$expected"
+
+test_begin_subtest "User defined section, positioned before search input"
+output=$(test_emacs "(setq notmuch-hello-sections '((:title \"Test-before\" :type eachtag :position before))) (notmuch-hello) (princ (buffer-string))")
+expected=$(cat $EXPECTED/notmuch-hello-section-before)
+test_expect_equal "$output" "$expected"
+
 test_begin_subtest "Basic notmuch-show view in emacs"
 maildir_storage_thread=$(notmuch search --output=threads id:20091117190054.GU3165@dottiness.seas.harvard.edu)
 output=$(test_emacs "(notmuch-show \"$maildir_storage_thread\") (princ (buffer-string))")
diff --git a/test/emacs.expected-output/notmuch-hello-new-section b/test/emacs.expected-output/notmuch-hello-new-section
new file mode 100644
index 0000000..23e0068
--- /dev/null
+++ b/test/emacs.expected-output/notmuch-hello-new-section
@@ -0,0 +1,17 @@
+   Welcome to notmuch. You have 50 messages.
+
+Saved searches: [edit]
+
+	  50 inbox           50 unread    
+
+Search:                                                                     
+
+Test: [hide]
+
+	  50 inbox     
+
+
+	 Type a search query and hit RET to view matching threads.
+		Edit saved searches with the `edit' button.
+  Hit RET or click on a saved search or tag name to view matching threads.
+    `=' refreshes this screen. `s' jumps to the search box. `q' to quit.
diff --git a/test/emacs.expected-output/notmuch-hello-section-before b/test/emacs.expected-output/notmuch-hello-section-before
new file mode 100644
index 0000000..a5781ce
--- /dev/null
+++ b/test/emacs.expected-output/notmuch-hello-section-before
@@ -0,0 +1,18 @@
+   Welcome to notmuch. You have 50 messages.
+
+Saved searches: [edit]
+
+	  50 inbox                 50 unread          
+
+Test-before [hide]
+
+	   4 attachment             7 signed          
+	  50 inbox                 50 unread          
+
+Search:                                                                     
+
+
+	 Type a search query and hit RET to view matching threads.
+		Edit saved searches with the `edit' button.
+  Hit RET or click on a saved search or tag name to view matching threads.
+    `=' refreshes this screen. `s' jumps to the search box. `q' to quit.
diff --git a/test/emacs.expected-output/notmuch-hello-section-counts b/test/emacs.expected-output/notmuch-hello-section-counts
new file mode 100644
index 0000000..c22d491
--- /dev/null
+++ b/test/emacs.expected-output/notmuch-hello-section-counts
@@ -0,0 +1,18 @@
+   Welcome to notmuch. You have 50 messages.
+
+Saved searches: [edit]
+
+	  50 inbox                 50 unread          
+
+Search:                                                                     
+
+Test-with-counts: [hide]
+
+	   2 attachment             7 signed          
+	   7 inbox                  7 unread          
+
+
+	 Type a search query and hit RET to view matching threads.
+		Edit saved searches with the `edit' button.
+  Hit RET or click on a saved search or tag name to view matching threads.
+    `=' refreshes this screen. `s' jumps to the search box. `q' to quit.
diff --git a/test/emacs.expected-output/notmuch-hello-section-hidden-tag b/test/emacs.expected-output/notmuch-hello-section-hidden-tag
new file mode 100644
index 0000000..d6d31b3
--- /dev/null
+++ b/test/emacs.expected-output/notmuch-hello-section-hidden-tag
@@ -0,0 +1,17 @@
+   Welcome to notmuch. You have 50 messages.
+
+Saved searches: [edit]
+
+	  50 inbox                 50 unread          
+
+Search:                                                                     
+
+Test-with-filtered: [hide]
+
+	   4 attachment            50 inbox                  7 signed          
+
+
+	 Type a search query and hit RET to view matching threads.
+		Edit saved searches with the `edit' button.
+  Hit RET or click on a saved search or tag name to view matching threads.
+    `=' refreshes this screen. `s' jumps to the search box. `q' to quit.
diff --git a/test/emacs.expected-output/notmuch-hello-section-with-empty b/test/emacs.expected-output/notmuch-hello-section-with-empty
new file mode 100644
index 0000000..7ab80f2
--- /dev/null
+++ b/test/emacs.expected-output/notmuch-hello-section-with-empty
@@ -0,0 +1,17 @@
+   Welcome to notmuch. You have 50 messages.
+
+Saved searches: [edit]
+
+	  50 inbox                 50 unread          
+
+Search:                                                                     
+
+Test-with-empty: [hide]
+
+	  50 inbox           
+
+
+	 Type a search query and hit RET to view matching threads.
+		Edit saved searches with the `edit' button.
+  Hit RET or click on a saved search or tag name to view matching threads.
+    `=' refreshes this screen. `s' jumps to the search box. `q' to quit.
-- 
1.7.5.3

